@@ -169,7 +169,7 @@ if conf_sign:
         "003D": "FLASH MATCH TYPE FAIL",
         "003E": "FLASH LOAD VERIFY FAIL",
         "003F": "FLASH BOOT FAIL",
-        "0040": "FLASH ID NOT FIT WITH BOOTHEADER",
+        "0040": "FLASH CFG NOT FIT WITH BOOTHEADER",
         "0050": "IMG LOAD SHAKEHAND FAIL",
         "0051": "IMG LOAD BOOT CHECK FAIL",
         "0060": "IMG CREATE FAIL",
@@ -301,7 +301,7 @@ else:
         "003D": "BFLB FLASH MATCH TYPE FAIL",
         "003E": "BFLB FLASH LOAD VERIFY FAIL",
         "003F": "BFLB FLASH BOOT FAIL",
-        "0040": "BFLB FLASH ID NOT FIT WITH BOOTHEADER",
+        "0040": "BFLB FLASH CFG NOT FIT WITH BOOTHEADER",
         "0050": "BFLB IMG LOAD SHAKEHAND FAIL",
         "0051": "BFLB IMG LOAD BOOT CHECK FAIL",
         "0060": "BFLB IMG CREATE FAIL",
